.. image:: https://github.com/gelles-brandeis/tapqir/raw/latest/docs/source/_static/logo.png
   :target: https://tapqir.readthedocs.io/
   :alt: Tapqir logo

*Bayesian analysis of co-localization single-molecule microscopy image data.*

---------

.. |ci| image:: https://github.com/gelles-brandeis/tapqir/workflows/build/badge.svg
  :target: https://github.com/gelles-brandeis/tapqir/actions

.. |docs| image:: https://readthedocs.org/projects/tapqir/badge/?version=latest
    :alt: Documentation Status
    :scale: 100%
    :target: https://tapqir.readthedocs.io/

.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
  :target: https://github.com/ambv/black
  
.. |DOI| image:: https://img.shields.io/badge/DOI-10.1101%2F2021.09.30.462536-blue
   :target: https://doi.org/10.1101/2021.09.30.462536
   :alt: DOI

|DOI| |ci| |docs| |black|

`Preprint <https://doi.org/10.1101/2021.09.30.462536>`_ |
`Documentation <https://tapqir.readthedocs.io/>`_ |
`Discussions <https://github.com/gelles-brandeis/tapqir/discussions/>`_

Please see the `Documentation`_ for further information.
